package
Version:
v0.0.0-...-7a8bbb0
Opens a new window with list of versions in this module.
Published: Mar 17, 2023
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type APIKeyResponse struct {
Status int `json:"status"`
Message string `json:"message"`
Key models.APIKey `json:"api_key"`
}
type APIKeysResponse struct {
Status int `json:"status"`
Message string `json:"message"`
Keys []models.APIKey `json:"api_keys"`
}
type AuthorizationResponse struct {
Status int `json:"status"`
Message string `json:"message"`
IsAuthorized bool `json:"is_authorized"`
}
type ErrorResponse struct {
Status int `json:"status"`
Message string `json:"message"`
IsAuthorized bool `json:"is_authorized"`
}
type GenericDeletedResponse struct {
Status int `json:"status"`
IsDeleted bool `json:"is_deleted"`
}
type GenericResponse struct {
Status int `json:"status"`
Message string `json:"message"`
Success bool `json:"success"`
}
type GenericSuccessResponse struct {
Status int `json:"status"`
Message string `json:"message"`
}
type KeyResponse struct {
Status int `json:"status"`
Message string `json:"message"`
IsAuthorized bool `json:"is_authorized"`
Key models.APIKey `json:"key"`
}
type UserDetailsResponse struct {
Status int `json:"status"`
Message string `json:"message"`
Email string `json:"email"`
Id primitive.ObjectID `bson:"_id" json:"_id,omitempty"`
UserType models.UserType `bson:"user_type" json:"user_type"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.